@@ -18,20 +18,21 @@
 #ifndef OPKG_DOWNLOAD_H
 #define OPKG_DOWNLOAD_H
 
-#include "opkg_conf.h"
+#include "config.h"
+#include "pkg.h"
 
 typedef void (*opkg_download_progress_callback)(int percent, char *url);
 typedef int (*curl_progress_func)(void *data, double t, double d, double ultotal, double ulnow);
 
 
-int opkg_download(opkg_conf_t *conf, const char *src, const char *dest_file_name, curl_progress_func cb, void *data);
-int opkg_download_pkg(opkg_conf_t *conf, pkg_t *pkg, const char *dir);
+int opkg_download(const char *src, const char *dest_file_name, curl_progress_func cb, void *data);
+int opkg_download_pkg(pkg_t *pkg, const char *dir);
 /*
  * Downloads file from url, installs in package database, return package name. 
  */
-int opkg_prepare_url_for_install(opkg_conf_t *conf, const char *url, char **namep);
+int opkg_prepare_url_for_install(const char *url, char **namep);
 
-int opkg_verify_file (opkg_conf_t *conf, char *text_file, char *sig_file);
+int opkg_verify_file (char *text_file, char *sig_file);
 #ifdef HAVE_CURL
 void opkg_curl_cleanup(void);
 #endif
