@@ -15,8 +15,6 @@
    General Public License for more details.
 */
 
-#include "includes.h"
-
 #include "void_list.h"
 #include "libbb/libbb.h"
 
@@ -26,7 +24,7 @@ void void_list_elt_init(void_list_elt_t *elt, void *data)
     elt->data = data;
 }
 
-void_list_elt_t * void_list_elt_new (void *data) {
+static void_list_elt_t * void_list_elt_new (void *data) {
     void_list_elt_t *elt;
     /* freed in void_list_elt_deinit */
     elt = xcalloc(1, sizeof(void_list_elt_t));
@@ -96,7 +94,7 @@ void *void_list_remove(void_list_t *list, void_list_elt_t **iter)
             break;
     }
     if ( pos != old_elt) {
-        fprintf(stderr, "%s: ERROR: element not found in list\n", __FUNCTION__);
+        opkg_msg(ERROR, "Internal error: element not found in list.\n");
         return NULL;
     }
 
